( cd usr/bin ; rm -rf gcc64 )
( cd usr/bin ; ln -sf gcc64-3.3.6 gcc64 )
( cd usr/bin ; rm -rf cc64 )
( cd usr/bin ; ln -sf gcc64 cc64 )
( cd usr/bin ; rm -rf sparc64-linux-gcc )
( cd usr/bin ; ln -sf gcc64-3.3.6 sparc64-linux-gcc )
